## autolog by eotinb
## contains variables to turn on and off various extra log messages
## Alt+E is always on

import os

## USER SETTINGS

## Txt file log echo options
path = "C:\Documents and Settings\Owner\My Documents\My Games\Sid Meier's Civilization 4\Saves\succession"
                                    ## directory where log file resides
logFile = "autolog.txt"             ## name of log file -- if there is no file of this name in the directory above, one will be created
style = 2                           ## basic pre-formatting: 0 = no formatting, 1 = HTML tags, 2 = forum tags
color = 1                           ## comments are color-coded for forum posts: 0 = color-coding off, 1 = color-coding on
prefixTag = "User comment: "        ## this is what will appear before custom user entries in the text log; if you don't want any prefix, set it to ""

AUTO_LOG_COMBAT = 1                 ## will log combat results involving your units
AUTO_LOG_TECH = 1                   ## will log techs aquired and research started
AUTO_LOG_COMPLETED_BUILDS = 1       ## will log when a city completes a build
AUTO_LOG_START_BUILDS = 1           ## will log when a city starts a build
AUTO_LOG_CITY_FOUNDED = 1           ## will log when you found a city
AUTO_LOG_CITY_GROWTH = 1            ## will log when one of your cities grows in population
AUTO_LOG_CITY_RAZED = 1             ## will log when you raze another civ's city or one of your cities is razed
AUTO_LOG_CITY_OWNERSHIP = 1         ## will log when you acquire or lose a city through conquest or trade
AUTO_LOG_BORDERS = 1                ## will log when one of your cities' borders expand
AUTO_LOG_PROJECTS = 1               ## will log completion of projects (certain wonders are technically projects -- other wonders are treated like normal buildings)
AUTO_LOG_PROMOTIONS = 1             ## will log when one of your units is promoted
AUTO_LOG_GOODIES = 1                ## will log results from popping tribal villages
AUTO_LOG_GREAT_PEOPLE = 1           ## will log the birth of great people (in your cities)
AUTO_LOG_RELIGION = 1               ## will log: 1.when you found a religion, 2. spread of any religion to your cities, and 3. spread of religions whose Holy city you control to foreign cities
AUTO_LOG_GOLDEN_AGE = 1             ## will log begin and end of your Golden Age
AUTO_LOG_CONTACT = 1                ## will log first contact with other civs
AUTO_LOG_WAR = 1                    ## will log start and end of wars involving you


## CODE

class autologInstance:

    def __init__(self, fileName):
        # file initialization
        self.fileName = fileName
        self.open()
    
        ## setting style variables
        self.blueOpenTag = ""
        self.blueCloseTag = ""
        self.greenOpenTag = ""
        self.greenCloseTag = ""
        self.redOpenTag = ""
        self.redCloseTag = ""
        self.orangeOpenTag = ""
        self.orangeCloseTag = ""
        self.purpleOpenTag = ""
        self.purpleCloseTag = ""
        self.brownOpenTag = ""
        self.brownCloseTag = ""
        self.yellowOpenTag = ""
        self.yellowCloseTag = ""
        if (style == 0):
            self.boldOpenTag = ""
            self.boldCloseTag = ""
            self.ulineOpenTag = ""
            self.ulineCloseTag = ""
        elif (style == 1):
            self.boldOpenTag = "<b>"
            self.boldCloseTag = "</b>"
            self.ulineOpenTag = "<u>"
            self.ulineCloseTag = "</u>"
        elif (style == 2):
            self.boldOpenTag = "[b]"
            self.boldCloseTag = "[/b]"
            self.ulineOpenTag = "[u]"
            self.ulineCloseTag = "[/u]"
            if (color == 1):
                self.blueOpenTag = '[color="RoyalBlue"]'
                self.blueCloseTag = '[/color]'
                self.greenOpenTag = '[color="Green"]'
                self.greenCloseTag = '[/color]'
                self.redOpenTag = '[color="Red"]'
                self.redCloseTag = '[/color]'
                self.orangeOpenTag = '[color="DarkOrange"]'
                self.orangeCloseTag = '[/color]'
                self.purpleOpenTag = '[color="Purple"]'
                self.purpleCloseTag = '[/color]'
                self.brownOpenTag = '[color="Brown"]'
                self.brownCloseTag = '[/color]'
                self.yellowOpenTag = '[color="Yellow"]'
                self.yellowCloseTag = '[/color]'
        self.headerOpenTag = self.boldOpenTag + self.ulineOpenTag
        self.headerCloseTag = self.boldCloseTag + self.ulineCloseTag

    def isOpen(self):
        ## not used at this time
        if (self.log.closed):
            return False
        else:
            return True

    def write(self, type, message, year = 0, turn = 0):
        ## fix formatting of year
        if (year < 0):
            year = str(year)[1:] + " BC"
        else:
            year = str(year) + " AD"
        ## determine type of message
        if (type == 0): ## turn header
            logMessage = "%sTurn %i (%s)%s\n" % (self.headerOpenTag, turn, year, self.headerCloseTag)
        elif (type == 1): ## no special formatting
            logMessage = message + "\n"
        elif (type == 2): ## custom user comment
            logMessage = "%s%s%s%s\n" % (self.boldOpenTag, prefixTag, self.boldCloseTag, message)
        elif (type == 3): ## combat note
            logMessage = "%s%s%s\n" % (self.redOpenTag, message, self.redCloseTag)
        elif (type == 4): ## city build notes
            logMessage = "%s%s%s\n" % (self.purpleOpenTag, message, self.purpleCloseTag)
        elif (type == 5): ## city notes
            logMessage = "%s%s%s\n" % (self.blueOpenTag, message, self.blueCloseTag)
        elif (type == 6): ## religion notes
            logMessage = "%s%s%s\n" % (self.orangeOpenTag, message, self.orangeCloseTag)
        elif (type == 7): ## technology notes
            logMessage = "%s%s%s\n" % (self.greenOpenTag, message, self.greenCloseTag)
        elif (type == 8): ## other notes (Golden Age, great people, tribal village results)
            logMessage = "%s%s%s\n" % (self.brownOpenTag, message, self.brownCloseTag)
        self.log.write(logMessage)
        self.close()
        self.open()

    def open(self):
        temppath = os.getcwd()
        os.chdir(path)
        self.log = open(self.fileName, 'a')
        os.chdir(temppath)
        return

    def close(self):
        self.log.close()
